@@ -192,9 +192,7 @@ class EventsRuleToStepFunctionProps:
         if isinstance(event_rule_props, dict):
             event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(state_machine_props, dict):
-            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(
-                **state_machine_props
-            )
+            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
         self._values = {
             "event_rule_props": event_rule_props,
             "state_machine_props": state_machine_props,
